AccountInfo class

Constructors

AccountInfo(String? accountId, AccountName? name, String? email, bool? emailVerified, String? profilePhotoUrl, bool? disabled, String? country, String? locale, String? referralLink, bool? isPaired, AccountType? accountType, RootInfo? rootInfo)
AccountInfo.fromMap(Map<String, dynamic> json)

Properties

accountId ↔ String?
getter/setter pair
accountType ↔ AccountType?
getter/setter pair
country ↔ String?
getter/setter pair
disabled ↔ bool?
getter/setter pair
email ↔ String?
getter/setter pair
emailVerified ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isPaired ↔ bool?
getter/setter pair
locale ↔ String?
getter/setter pair
name ↔ AccountName?
getter/setter pair
profilePhotoUrl ↔ String?
getter/setter pair
getter/setter pair
rootInfo ↔ RootInfo?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited