AccountName class

Constructors

AccountName(String? givenName, String? surname, String? familiarName, String? displayName, String? abbreviatedName)
AccountName.fromMap(Map<String, dynamic> json)

Properties

abbreviatedName ↔ String?
getter/setter pair
displayName ↔ String?
getter/setter pair
familiarName ↔ String?
getter/setter pair
givenName ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
surname ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited